@@ -1,5 +1,5 @@
 package App::pherkin;
-$App::pherkin::VERSION = '0.30';
+$App::pherkin::VERSION = '0.32';
 use strict;
 use warnings;
 
@@ -23,7 +23,7 @@ App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.30
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -61,10 +61,10 @@ sub run {
 
     my ( $options, @feature_files ) = $self->_process_arguments(@arguments);
 
+    my $features_path = $feature_files[0] || './features/';
     my ( $executor, @features ) =
-      Test::BDD::Cucumber::Loader->load( $feature_files[0] || './features/',
-        $self->tag_scheme );
-    die "No feature files found" unless @features;
+      Test::BDD::Cucumber::Loader->load( $features_path, $self->tag_scheme );
+    die "No feature files found in $features_path" unless @features;
 
     my $harness = $self->_load_harness( $options->{'harness'} );
 
@@ -101,7 +101,7 @@ sub _process_arguments {
     local @ARGV = @args;
 
     # Allow -Ilib, -bl
-    Getopt::Long::Configure('bundling');
+    Getopt::Long::Configure( 'bundling', 'pass_through' );
 
     my $includes = [];
     my $tags     = [];
@@ -137,7 +137,7 @@ sub _process_arguments {
     # Store our TagSpecScheme
     $self->tag_scheme( $self->_process_tags( @{$tags} ) );
 
-    return ( { harness => $harness }, @ARGV );
+    return ( { harness => $harness }, pop @ARGV );
 }
 
 sub _process_tags {
